@@ -255,10 +255,10 @@ class ConfigInfoData(object):
         "nmr-mr-path-list": (["json"], "nmr-mr-path-list"),
         "component-image": (["jpg", "png", "gif", "svg", "tif", "tiff"], "ccimg"),
         "component-definition": (["pdbx", "sdf"], "ccdef"),
-        "em-volume": (["map", "ccp4", "mrc2000"], "em-volume"),
-        "em-mask-volume": (["map", "ccp4", "mrc2000"], "em-mask-volume"),
-        "em-additional-volume": (["map", "ccp4", "mrc2000"], "em-additional-volume"),
-        "em-half-volume": (["map", "ccp4", "mrc2000"], "em-half-volume"),
+        "em-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-volume"),
+        "em-mask-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-mask-volume"),
+        "em-additional-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-additional-volume"),
+        "em-half-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-half-volume"),
         "em-volume-wfcfg": (["json"], "em-volume-wfcfg"),
         "em-mask-volume-wfcfg": (["json"], "em-mask-volume-wfcfg"),
         "em-additional-volume-wfcfg": (["json"], "em-additional-volume-wfcfg"),
@@ -310,6 +310,7 @@ class ConfigInfoData(object):
         "validation-report-2fo-map-coef": (["pdbx"], "val-report-wwpdb-2fo-fc-edmap-coef"),
         "validation-report-fo-map-coef": (["pdbx"], "val-report-wwpdb-fo-fc-edmap-coef"),
         "validation-report-images": (["tar"], "val-report-images"),
+        "map-xray": (["bcif"], "map-xray"),
         "map-2fofc": (["map"], "map-2fofc"),
         "map-fofc": (["map"], "map-fofc"),
         "map-omit-2fofc": (["map"], "map-omit-2fofc"),
@@ -407,6 +408,7 @@ class ConfigInfoData(object):
         "xml": "xml",
         "pdf": "pdf",
         "map": "map",
+        "bcif": "bcif",
         "amber": "amber",
         "amber-aux": "amber-aux",
         "cns": "cns",
